# Release 0.8.35

!!!tip inline end "Need Help?"
    The SuperCowPowers team is happy to give any assistance needed when setting up AWS and Workbench. So please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 

The Workbench framework continues to flex to support different real world use cases when operating a set of production machine learning pipelines.

**Note:** These release notes cover the changes from `0.8.33` to `0.8.35`


### General
**Workbench REPL:** The REPL now has a workaround for the current iPython embedded shell namespace scoping issue. See: [iPython Embedded Shell Scoping Issue](https://github.com/ipython/ipython/issues/12199). So this pretty much means the REPL is 110% more **awesome** now!


### API Changes
None
	
### Improvements/Fixes
**AWS Service Broker:**
The AWS service broker was dramatic when it pulls meta data for something that just got deleted (or partially deleted), it was throwing CRITICAL log messages. We've refined the AWS error handling so that it's more granular about the error_codes for Validation or ResourceNotFound exceptions those are reduced to WARNINGS.

**ROCAUC modifications:** Version `0.8.33` put in quite a few changes, for `0.8.35` we've also added logic to both validate and ensure proper order of the probability columns with the class labels.

## Specific Code Changes
 
<a href="https://github.com/supercowpowers/workbench/compare/v0.8.33...v0.8.35" target="_blank">Code Diff v0.8.33 --> v0.8.35</a> 

Who doesn't like looking at code! Also +3 points for getting down this far! Here's a cow joke as a reward:

> ***What do you call a cow with no legs?
    ........Ground beef.***

## Questions?
<img align="right" src="../../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


